@@ -113,15 +113,6 @@ def up(
     # environment variables for container
     envs.update({"RESULT_PATH": result_path.as_posix()})
 
-    # Sentry environment variables for container
-    if hasattr(settings, "SENTRY_DSN"):
-        envs.update(
-            {
-                "SENTRY_DSN": settings.SENTRY_DSN,
-                "RELEASE": getattr(settings, "SENTRY_RELEASE", ""),
-            }
-        )
-
     if hasattr(settings, "CONTAINER_LOG_LEVEL") and "LOG_LEVEL" not in envs:
         envs.update({"LOG_LEVEL": settings.CONTAINER_LOG_LEVEL})
 
